# Microsoft Entra ID Integration for SaaS Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#introduction)
  * [Implementation Details](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#implementation-details)
  * [Discovery Capabilities](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#discovery-capabilities)
  * [Setting up Microsoft Entra ID Integration](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#setting-up-microsoft-entra-id-integration)
  * [Register SAP LeanIX in Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#register-sap-leanix-in-microsoft-entra-id)
  * [Grant Permissions to SAP LeanIX](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#grant-permissions-to-sap-leanix)
  * [Gather Configuration Settings](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#gather-configuration-settings)
  * [Enter the Copied Credentials in SAP LeanIX](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery#enter-the-copied-credentials-in-sap-leanix)


Set up an integration with Microsoft Entra ID to streamline the discovery of your SaaS applications.
